==> central-repository-3.60.0.zip: com/microej/pack/ecom-wifi/ecom-wifi-pack/1.0.0/CHANGELOG-1.0.0.md <==
# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.0] - 2023-02-27

### Added

- Initialization native.

### Changed

- Split the net-addons pack into: ecom-network-pack and ecom-wifi-pack.
- Update to BSD-style license.
- Align with the PACK project template.

### Removed

- Deprecated files.

## net-addons pack [2.5.3] - 2022-05-09

### Fixed

- ECOM-WIFI-IMPL 2.3.1: Check validity of passphrases and SSIDs to match specification.
- ECOM-WIFI-IMPL 2.3.1: Encode and decode SSIDs with UTF-8 charset when available.

## net-addons pack [2.5.2] - 2021-10-08

### Changed

- ECOM-WIFI modules migrated to MMM.

## net-addons pack [2.5.1] - 2021-06-25

### Fixed

- Fix Ivy configuration for pack publication

## net-addons pack [2.5.0] - 2021-06-17

### Added

- ECOM-WIFI API 2.2.1: Add null-analysis
- ECOM-WIFI IMPL 2.3.0: Add soft AP state native (LLAPI 1.2.0)
- ECOM-WIFI MOCK 1.5.0: Implement soft AP state native

### Changed

- ECOM-WIFI IMPL 2.3.0: Remove Wi-Fi state cache

### Fixed

- ECOM-WIFI MOCK 1.5.0: Fix Wi-Fi station state native

## net-addons pack [2.4.0] - 2020-11-23

### Added

- Add a way to set a default network interface in ECOM-NETWORK.

## net-addons pack [2.3.0] - 2020-11-03

### Added

- Add support for WP3 WiFi security mode.

### Fixed

- WiFi scan now returns all successfully scanned APs even if one AP scan fails.

## net-addons pack [2.2.0] - 2020-07-31

### Added

- Update License to LAW-0011-LCS-MicroEJSDK-EULA-3.0-B
- Keep the security mode when joining a network using an access point and a passphrase

## net-addons pack [2.1.6] - 2019-11-19

### Fixed

- Property loading for capability.

## net-addons pack [2.1.5] - 2019-10-10

### Fixed

- Allow Wi-Fi join while SoftAP is enabled if the platform supports simultaneous modes

## net-addons pack [2.1.4] - 2019-10-01

### Fixed

- Fix IllegalArgumentException that occurred when scanning Wi-Fi  and a SSID of 32 characters is visible.  

## net-addons pack [2.1.3] - 2019-09-09

### Fixed

- Fix NPE thrown if joining before scan.

## net-addons pack [2.1.2] - 2019-09-05

### Fixed

- Add workbench extension in group.

## net-addons pack [2.1.1] - 2019-08-21

### Fixed

- Update Wi-Fi mock.
- Fix ivy fixed module.

## net-addons pack [2.1.0] - 2019-07-05

### Added

- Add Wi-Fi mock and Workbench extention.

## net-addons pack [2.0.3] - 2018-08-29

### Fixed

- SoftApConfiguration name must be set when enableSoftAP called.

## net-addons pack [2.0.2] - 2018-07-19

### Fixed

- Generic Net Addons pack.

## net-addons pack [2.0.1] - 2018-04-27

### Fixed

- NullPointerException thrown when toString() method call on IPConfiguration instance.

## net-addons pack [2.0.0] - 2018-03-06

### Added

- Architecture compatibility major version upgraded.

## net-addons pack [1.1.2] - 2017-03-15

### Fixed

- Libraries low level API packaged MicroEJ C Component (C header files versioning).

## net-addons pack [1.1.1] - 2017-03-10

### Fixed

- Wrong API versionning.
- Missing metadata in low level API files.

## net-addons pack [1.1.0] - 2016-11-22

### Added

- All Wifi Access Point could be joined (remove restriction on WPA2 Access Point).

## net-addons pack [1.0.2] - 2016-09-01

### Added

- Release for Enero with set softAP name.

## net-addons pack [1.0.0] - 2016-07-04

### Added

- Initial revision.

---
_Copyright 2015-2023 MicroEJ Corp. All rights reserved._
_Use of this source code is governed by a BSD-style license that can be found with this software._

==> central-repository-3.63.0.zip: com/microej/pack/ecom-wifi/ecom-wifi-pack/1.0.1/CHANGELOG-1.0.1.md <==
# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.1] - 2023-11-17

### Fixed

- ECOM-WIFI-IMPL 2.3.3: Fix security modes low level definitions.
- ECOM-WIFI-IMPL 2.3.3: Fix passphrase validity check for OPEN and WEP security modes.

## [1.0.0] - 2023-02-27

### Added

- Initialization native.

### Changed

- Split the net-addons pack into: ecom-network-pack and ecom-wifi-pack.
- Update to BSD-style license.
- Align with the PACK project template.

### Removed

- Deprecated files.

## net-addons pack [2.5.3] - 2022-05-09

### Fixed

- ECOM-WIFI-IMPL 2.3.1: Check validity of passphrases and SSIDs to match specification.
- ECOM-WIFI-IMPL 2.3.1: Encode and decode SSIDs with UTF-8 charset when available.

## net-addons pack [2.5.2] - 2021-10-08

### Changed

- ECOM-WIFI modules migrated to MMM.

## net-addons pack [2.5.1] - 2021-06-25

### Fixed

- Fix Ivy configuration for pack publication

## net-addons pack [2.5.0] - 2021-06-17

### Added

- ECOM-WIFI API 2.2.1: Add null-analysis
- ECOM-WIFI IMPL 2.3.0: Add soft AP state native (LLAPI 1.2.0)
- ECOM-WIFI MOCK 1.5.0: Implement soft AP state native

### Changed

- ECOM-WIFI IMPL 2.3.0: Remove Wi-Fi state cache

### Fixed

- ECOM-WIFI MOCK 1.5.0: Fix Wi-Fi station state native

## net-addons pack [2.4.0] - 2020-11-23

### Added

- Add a way to set a default network interface in ECOM-NETWORK.

## net-addons pack [2.3.0] - 2020-11-03

### Added

- Add support for WP3 WiFi security mode.

### Fixed

- WiFi scan now returns all successfully scanned APs even if one AP scan fails.

## net-addons pack [2.2.0] - 2020-07-31

### Added

- Update License to LAW-0011-LCS-MicroEJSDK-EULA-3.0-B
- Keep the security mode when joining a network using an access point and a passphrase

## net-addons pack [2.1.6] - 2019-11-19

### Fixed

- Property loading for capability.

## net-addons pack [2.1.5] - 2019-10-10

### Fixed

- Allow Wi-Fi join while SoftAP is enabled if the platform supports simultaneous modes

## net-addons pack [2.1.4] - 2019-10-01

### Fixed

- Fix IllegalArgumentException that occurred when scanning Wi-Fi  and a SSID of 32 characters is visible.  

## net-addons pack [2.1.3] - 2019-09-09

### Fixed

- Fix NPE thrown if joining before scan.

## net-addons pack [2.1.2] - 2019-09-05

### Fixed

- Add workbench extension in group.

## net-addons pack [2.1.1] - 2019-08-21

### Fixed

- Update Wi-Fi mock.
- Fix ivy fixed module.

## net-addons pack [2.1.0] - 2019-07-05

### Added

- Add Wi-Fi mock and Workbench extention.

## net-addons pack [2.0.3] - 2018-08-29

### Fixed

- SoftApConfiguration name must be set when enableSoftAP called.

## net-addons pack [2.0.2] - 2018-07-19

### Fixed

- Generic Net Addons pack.

## net-addons pack [2.0.1] - 2018-04-27

### Fixed

- NullPointerException thrown when toString() method call on IPConfiguration instance.

## net-addons pack [2.0.0] - 2018-03-06

### Added

- Architecture compatibility major version upgraded.

## net-addons pack [1.1.2] - 2017-03-15

### Fixed

- Libraries low level API packaged MicroEJ C Component (C header files versioning).

## net-addons pack [1.1.1] - 2017-03-10

### Fixed

- Wrong API versionning.
- Missing metadata in low level API files.

## net-addons pack [1.1.0] - 2016-11-22

### Added

- All Wifi Access Point could be joined (remove restriction on WPA2 Access Point).

## net-addons pack [1.0.2] - 2016-09-01

### Added

- Release for Enero with set softAP name.

## net-addons pack [1.0.0] - 2016-07-04

### Added

- Initial revision.

---
_Copyright 2015-2023 MicroEJ Corp. All rights reserved._
_Use of this source code is governed by a BSD-style license that can be found with this software._
